﻿/** 
 *   Copyright 2008 Olivian Daniel Tofan
 * 
 *   This file is part of WLPGZenphotoPlugin.
 *
 *   WLPGZenphotoPlugin is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Foobar is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Collections.Generic;
using System.Text;

namespace WLPGZenphotoPlugin
{
    internal class Session
    {
        private const string ZENFOLDER = "zp-core";
        public string Name;
        public string Url;
        public string Username;
        public string Password;

        /// <summary>
        /// Constructor insures the class is initialized properly.
        /// </summary>
        public Session(string Name, string Url)
        {
            this.Name = Name;
            this.Url = Url;
            this.Username = null;
            this.Password = null;
        }

        public Session(Session session)
        {
            this.Name = session.Name;
            this.Url = session.Url;
            this.Username = session.Username;
            this.Password = session.Password;
        }

        /// <summary>
        /// This function is used by the ComboBox control. When you add an 
        /// Session object to the ComboBox.Items collection this function 
        /// will be called to determine the text to be displayed.
        /// </summary>
        /// <returns>The string to be displayed in the ComboBox.</returns>
        public override string ToString()
        {
            return this.Name;
        }

        public string ToLog()
        {
            return "Session: \r\n" +
                    "\tName: " + Name + "\r\n" +
                    "\tUrl: " + Url + "\r\n" +
                    "\tUsername: " + Username + "\r\n" +
                    "\tPassword: " + Password;
        }

        public Uri GetLoginUri()
        {
            string after = string.Empty;

            if (!Url.EndsWith("/"))
            {
                after = "/";
            }
            return new Uri(Url + after + ZENFOLDER + "/admin.php");
        }

        public Uri GetUploadUri()
        {
            string after = string.Empty;

            if (!Url.EndsWith("/"))
            {
                after = "/";
            }
            return new Uri(Url + after + ZENFOLDER + "/admin-upload.php?action=upload");
        }

        public Uri GetAlbumsUri()
        {
            string after = string.Empty;

            if (!Url.EndsWith("/"))
            {
                after = "/";
            }
            return new Uri(Url + after + ZENFOLDER + "/admin-upload.php");
        }
    }

    class Album
    {
        private string name;
        private string folder;

        public Album(string folder)
        {
            this.name = string.Empty;
            this.folder = folder;
        }

        public Album(String name, string folder)
        {
            this.name = name;
            this.folder = folder;
        }

        /// <summary>
        /// This function is used by the ComboBox control. When you add an 
        /// Album object to the ComboBox.Items collection this function 
        /// will be called to determine the text to be displayed.
        /// </summary>
        /// <returns>The string to be displayed in the ComboBox.</returns>
        public override string ToString()
        {
            if (Name != null & Name.Trim().Length != 0) 
            {
                return Folder + "(" + Name + ")";
            }
            else 
            {
                if (Folder.Trim() != "")
                {
                    return Folder;
                }
                else
                {
                    return "/";
                }
            }
        }

        public bool IsRoot()
        {
            return (Folder.Trim() == "");
        }

        public string Name
        {
            get
            {
                return name;
            }
        }

        public string Folder
        {
            get
            {
                return folder;
            }
        }
    }

    /// <summary>
    /// The PhotoAttributes class is used to contain all the data that describes
    /// a photo. It is used during the upload process. 
    /// In C++ this would be a struct instead of a class since it is 
    /// merely meant to be a lightweight container for a collection of 
    /// properties, however, in C# structs are value types that get boxed, 
    /// unboxed and copied all over so we don't want that.
    /// </summary>
    internal class PhotoAttributes
    {
        public string Id;
        public string Filename;
        public string Title;
        public string Description;
        public List<string> Tags;

        /// <summary>
        /// Constructor insures the class is initialized properly.
        /// </summary>
        public PhotoAttributes()
        {
            this.Tags = new List<string>();
        }

        /// <summary>
        /// Constructor insures the class is initialized properly.
        /// </summary>
        public PhotoAttributes(string id, string filename, string title, string description, List<string> tags)
        {
            this.Id = id;
            this.Filename = filename;
            this.Title = title;
            this.Description = description;
            this.Tags = tags;
        }
    }

    class UploadData
    {
        public Album parentAlbum;
        public bool isNewAlbum;
        public bool isPublic;
        public Album newAlbum;

        public UploadData()
        {
            parentAlbum = null;
            isNewAlbum = false;
            isPublic = false;
            newAlbum = null;
        }
    }
}
