﻿/** 
 *   Copyright 2008 Olivian Daniel Tofan
 * 
 *   This file is part of WLPGZenphotoPlugin.
 *
 *   WLPGZenphotoPlugin is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Foobar is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Collections.Generic;
using System.Text;

namespace WLPGZenphotoPlugin
{
    class Log
    {
        public static bool DEBUG = false;

        public static void Error(string message)
        {
            string msg = System.String.Format("ERROR: {0}", message);
            LogMessageToFile(msg);
        }

        public static void Error(Exception e)
        {
            string msg = System.String.Format("ERROR: {0}\r\n{1}\r\n{2}", e.Message, e.GetType(), e.StackTrace);
            while (e.InnerException != null) 
            {
                msg = System.String.Format("\r\n caused by {0}\r\n{1}\r\n{1}", e.Message, e.GetType(), e.StackTrace);
                e = e.InnerException;
            }
            LogMessageToFile(msg);

        }

        public static void Info(string message)
        {
            string msg = System.String.Format("INFO: {0}", message);
            LogMessageToFile(msg);
        }

        public static void Debug(string message)
        {
            if (DEBUG) 
            {
                string msg = System.String.Format("DEBUG: {0}", message);
                LogMessageToFile(msg);
            }
        }

        private static string GetTempPath()
        {
            string path = System.Environment.GetEnvironmentVariable("TEMP");
            if (!path.EndsWith("\\"))
            {
                path += "\\";
            }
            return path;
        }

        private static void LogMessageToFile(string message)
        {
            System.IO.StreamWriter sw = System.IO.File.AppendText(
                GetTempPath() + "WLPGZenphotoPlugin.log");
            try
            {
                string logLine = System.String.Format(
                    "{0:G}: {1}", System.DateTime.Now, message);
                sw.WriteLine(logLine);
            }
            finally
            {
                sw.Close();
            }
        }
    }
}
